@@ -508,12 +508,12 @@ JavaSupportPart::parseProject( )
     TQMap< TQString, TQPair<uint, uint> > pcs;
 
     if( TQFileInfo( project()->projectDirectory() + "/" +
-			    project()->projectName().lower() + ".tdevelop.pcs" ).exists() )
+			    project()->projectName().lower() + ".kdevelop.pcs" ).exists() )
     {
-        d.rename(project()->projectName().lower() + ".tdevelop.pcs",
-			project()->projectName() + ".tdevelop.pcs");
+        d.rename(project()->projectName().lower() + ".kdevelop.pcs",
+			project()->projectName() + ".kdevelop.pcs");
     }
-    TQFile f(project()->projectDirectory() + "/" + project()->projectName() + ".tdevelop.pcs");
+    TQFile f(project()->projectDirectory() + "/" + project()->projectName() + ".kdevelop.pcs");
     if( f.open(IO_ReadOnly) ){
 	stream.setDevice( &f );
 
@@ -846,7 +846,7 @@ void JavaSupportPart::saveProjectSourceInfo( )
 	return;
 
     TQFile f( project()->projectDirectory() + "/" +
-		    project()->projectName() + ".tdevelop.pcs" );
+		    project()->projectName() + ".kdevelop.pcs" );
     if( !f.open( IO_WriteOnly ) )
 	return;
 
