@@ -45,6 +45,10 @@
 	(medium->isMounted() ? TQString("_mount") : TQString("_unmount")) +									\
 	(medium->isEncrypted() ? (sdevice->isDiskOfType(TDEDiskDeviceType::UnlockedCrypt) ? "_decrypt" : "_encrypt") : "" )			\
 	)
+#define MOUNTED_ICON_SUFFIX (															\
+	(medium->isMounted() ? TQString("-mounted") : TQString("")) +									\
+	(medium->isEncrypted() ? (sdevice->isDiskOfType(TDEDiskDeviceType::UnlockedCrypt) ? "-decrypted" : "-encrypted") : "" )			\
+	)
 
 #define CHECK_FOR_AND_EXECUTE_AUTOMOUNT(udi, medium, allowNotification) {									\
 		TQMap<TQString,TQString> options = MediaManagerUtils::splitOptions(mountoptions(udi));						\
@@ -163,7 +167,8 @@ void TDEBackend::AddDevice(TDEStorageDevice * sdevice, bool allowNotification)
 		/* We also don't display devices that underlie other devices;
 		*  e.g. the raw partition of a device mapper volume
 		*/
-		else if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::UsedByDevice)) {
+		else if (sdevice->checkDiskStatus(TDEDiskDeviceStatus::UsedByDevice)
+			 || (sdevice->fileSystemUsage().upper() == "RAID")) {
 			//
 		}
 		else {
@@ -728,43 +733,40 @@ void TDEBackend::setVolumeProperties(Medium* medium)
 			diskLabel = i18n("%1 Fixed Disk (%2)").arg(sdevice->deviceFriendlySize(), sdevice->deviceNode());
 		}
 
-		if (sdevice->isDiskOfType(TDEDiskDeviceType::USB)) {
+		if (sdevice->isDiskOfType(TDEDiskDeviceType::USB)
+		    || sdevice->checkDiskStatus(TDEDiskDeviceStatus::Removable)
+		    || sdevice->checkDiskStatus(TDEDiskDeviceStatus::Hotpluggable)) {
 			mimeType = "media/removable" + MOUNT_SUFFIX;
 			if (useDefaultLabel) {
 				diskLabel = i18n("%1 Removable Device").arg(sdevice->deviceFriendlySize());
 			}
+		}
 
-			medium->needMounting();
-
-			if (sdevice->isDiskOfType(TDEDiskDeviceType::CompactFlash)) {
-				medium->setIconName("compact_flash" + MOUNT_ICON_SUFFIX);
-			}
-			if (sdevice->isDiskOfType(TDEDiskDeviceType::MemoryStick)) {
-				medium->setIconName("memory_stick" + MOUNT_ICON_SUFFIX);
-			}
-			if (sdevice->isDiskOfType(TDEDiskDeviceType::SmartMedia)) {
-				medium->setIconName("smart_media" + MOUNT_ICON_SUFFIX);
-			}
-			if (sdevice->isDiskOfType(TDEDiskDeviceType::SDMMC)) {
-				medium->setIconName("sd_mmc" + MOUNT_ICON_SUFFIX);
-			}
-			if (sdevice->isDiskOfType(TDEDiskDeviceType::MediaDevice)) {
-				medium->setIconName("ipod" + MOUNT_ICON_SUFFIX);
-
-				if (sdevice->vendorModel().upper().contains("IPOD") && KProtocolInfo::isKnownProtocol( TQString("ipod") ) )
-				{
-					medium->unmountableState( "ipod:/" );
-					medium->mountableState(!sdevice->mountPath().isNull());
-				}
-			}
-			if (sdevice->isDiskOfType(TDEDiskDeviceType::Tape)) {
-				medium->setIconName("magnetic_tape" + MOUNT_ICON_SUFFIX);
-			}
-			if (medium->isMounted() && TQFile::exists(medium->mountPoint() + "/dcim"))
-			{
-				mimeType = "media/camera" + MOUNT_SUFFIX;
+		if (sdevice->isDiskOfType(TDEDiskDeviceType::CompactFlash)) {
+			medium->setIconName("media-flash-compact_flash" + MOUNTED_ICON_SUFFIX);
+		}
+		if (sdevice->isDiskOfType(TDEDiskDeviceType::MemoryStick)) {
+			medium->setIconName("media-flash-memory_stick" + MOUNTED_ICON_SUFFIX);
+		}
+		if (sdevice->isDiskOfType(TDEDiskDeviceType::SmartMedia)) {
+			medium->setIconName("media-flash-smart_media" + MOUNTED_ICON_SUFFIX);
+		}
+		if (sdevice->isDiskOfType(TDEDiskDeviceType::SDMMC)) {
+			medium->setIconName("media-flash-sd_mmc" + MOUNTED_ICON_SUFFIX);
+		}
+		if (sdevice->isDiskOfType(TDEDiskDeviceType::MediaDevice)) {
+			medium->setIconName("ipod" + MOUNT_ICON_SUFFIX);
+			if (sdevice->vendorModel().upper().contains("IPOD") && KProtocolInfo::isKnownProtocol( TQString("ipod") ) ) {
+				medium->unmountableState( "ipod:/" );
+				medium->mountableState(!sdevice->mountPath().isNull());
 			}
 		}
+		if (sdevice->isDiskOfType(TDEDiskDeviceType::Tape)) {
+			medium->setIconName("media-tape" + MOUNTED_ICON_SUFFIX);
+		}
+		if (medium->isMounted() && TQFile::exists(medium->mountPoint() + "/dcim")) {
+			mimeType = "media/camera" + MOUNT_SUFFIX;
+		}
 	}
 
 	if (!medium->needMounting()) {
